@@ -4,6 +4,20 @@ server <- function(input, output, session) {
   #   tags$style(HTML(paste0(".main-sidebar{width: ", input$sidebarwidth,"%;}")))
   # })
   
+  # register entrance and exit time entries
+  observe({
+    dd <- data.frame(id=session$token, start=as.character(Sys.time()),end=NA,app="compareGroups") # canviar a compareGroups/compareGroups_datarus segons si es fa el deploy a regicor o isubirana
+    googlesheets4::sheet_append(sheet_id, dd)
+  })
+  onStop(
+    function(){
+      dd <- data.frame(id=session$token, start=NA,end=as.character(Sys.time()),app="compareGroups") # canviar a compareGroups/compareGroups_datarus segons si es fa el deploy a regicor o isubirana
+      #print(dd)
+      googlesheets4::sheet_append(sheet_id, dd)
+      #print("xxxx")
+    }
+  )
+
   output$xxx <- renderPrint({
     # cat("summary(rv$dataset)\n")
     # print(summary(rv$dataset))
@@ -13,7 +27,8 @@ server <- function(input, output, session) {
     # cat("-----------------\n")
     # cat("summary(rv$datasetorigfiltered)\n")
     # print(summary(rv$datasetorigfiltered)) 
-    print(input$sepSNPs)
+    # print(input$sepSNPs)
+    input$rightPanel
   })
   
   output$github <- renderUser({
@@ -25,14 +40,7 @@ server <- function(input, output, session) {
       )        
     )
   })
-  
-  # observeEvent(input$showci,{
-  #   if (!is.null(input$showci) && input$showci)
-  #     hide("formatAccordion")
-  #   else
-  #     show("formatAccordion")
-  # })
-  
+
   observe({
     type <- if(is.null(input$type)) 1 else as.character(input$type)
     showci <- if(is.null(input$showci)) FALSE else input$showci
@@ -97,36 +105,20 @@ server <- function(input, output, session) {
     else
       shinyjs::hide("dropdownDescriptives")
   })
-
-
-  output$leftPanelAspect <- renderUI({
-    HTML(paste0("<style type='text/css'> #leftPanel{color:white;background-color:rgba(60,141,188,1);width:",input$leftPanelWidth,"%</style>"))
-  })
-
-  output$rightPanelAspect <- renderUI({
-    leftPanelWidth <- input$leftPanelWidth
-    if (leftPanelWidth>70)
-      rightPanelWidth <- 100
-    else
-      rightPanelWidth <- 100 - leftPanelWidth
-    if (input$leftmenu=='Home'){
-      rightPanelWidth <- 100
-    }
-    HTML(paste0("<style type='text/css'> #rightPanel{padding-left:3%;width:",rightPanelWidth,"%;height:50%</style>"))
-  })
-
-  observeEvent(input$leftPanelWidth, {
-    if (input$leftPanelWidth<5)
-      shinyjs::hide("leftPanel")
-    else
-      shinyjs::show("leftPanel")
-  })
-
+  
+  # right panel
   observeEvent(input$leftmenu,{
-    updateSliderInput(session, "leftPanelWidth", value=30)
+    if (input$leftmenu=='Home'){
+      if (input$rightPanel){ # close right panel
+        updateControlbar("rightPanel")  
+      }
+    }else{
+      if (!input$rightPanel){ # open right panel
+        updateControlbar("rightPanel")  
+      }
+    }
   })
 
-
   ## when data is loaded show the rest of menuItems
   observeEvent(rv$datasetorig, {
     if (NROW(rv$datasetorig)==0){
@@ -342,42 +334,6 @@ server <- function(input, output, session) {
     cc <- rv$SNPsHeaderColor
     HTML(paste0("<i style='margin-left:10px; color:",cc,"' class='fa fa-dna'></i><format style='color:",cc,"; font-weight:bold; padding-left:10px; font-size:20px'>SNPs</format>"))
   })   
-  
-  
-  observeEvent(input$toggleLeftPanel,{
-    shinyjs::hide("leftPanel",anim=FALSE)
-    updateSliderInput(session, "leftPanelWidth", value=0)  
-  })
-  
-  # observe({
-  #   if (is.null(input$dimension) || is.null(input$toggleLeftPanel)) return(NULL)
-  #   if (input$toggleLeftPanel%%2==0){
-  #     shinyjs::show("leftPanel",anim=FALSE)
-  #     widthLeftPanel <- 30
-  #     if (input$leftmenu=='Home')
-  #       widthLeftPanel <- 0
-  #     else {
-  #       if (input$dimension[1]<900) widthLeftPanel <- 100
-  #       # if (input$dimension[1]>=600 & input$dimension[1]<900) widthLeftPanel <- 50
-  #       # if (input$dimension[1]>=900) widthLeftPanel <- 30
-  #     }
-  #     updateSliderInput(session, "leftPanelWidth", value=widthLeftPanel)
-  #   } else {
-  #     shinyjs::hide("leftPanel",anim=FALSE)
-  #     updateSliderInput(session, "leftPanelWidth", value=0)
-  #   }
-  # })
-
-  observeEvent(input$leftmenu,{
-    if (input$leftmenu=='Home'){
-      shinyjs::hide("leftPanel")
-      # updateCheckboxInput(session, "toggleLeftPanel", value=FALSE)
-    }else{
-      shinyjs::show("leftPanel")
-      # updateCheckboxInput(session, "toggleLeftPanel", value=TRUE)
-    }
-  })
-
 
   ##### hide show load data options #####
 
@@ -539,6 +495,19 @@ server <- function(input, output, session) {
     rv$dataset <- rv$datasetorig
     rv$recodedvars <- c(rv$recodedvars, input$newvarname)
   })
+  
+  # convert to factor
+  observeEvent(rv$dataset,{
+    if (nrow(rv$dataset)==0) return(invisible(NULL))
+    vv <- names(rv$dataset)[sapply(rv$dataset, function(x) !is.Surv(x) & is.numeric(x))]
+    updateSelectInput(session, "vartofactor", choices=vv, selected=input$vartofactor)
+  })
+  observeEvent(input$vartofactorbtn, {
+    if (nrow(rv$dataset)==0) return(invisible(NULL))
+    lab <- attr(rv$dataset[,input$vartofactor], "label")
+    rv$dataset[,input$vartofactor] <- as.factor(rv$dataset[,input$vartofactor])
+    attr(rv$dataset[,input$vartofactor], "label") <- lab
+  })
 
   observeEvent(input$removenewvarok,{
     updateTextInput(session, "newvarname", value="")
@@ -662,7 +631,6 @@ server <- function(input, output, session) {
   observeEvent(input$resetbtn,{
     on.exit({shinyjs::hide("resetbtnPanel")})
     # reset all inputs!!!
-    # shinyjs::reset("leftPanel")
     rv$selevars<-rv$method<-rv$descdigits<-rv$ratiodigits<-rv$refratiocat<-rv$factratio<-rv$xhide<-rv$varsubset<-NULL
     rv$initial<-FALSE
     rv$datasetorig <- rv$dataset <- rv$datasetorigfiltered <- data.frame()
@@ -701,12 +669,9 @@ server <- function(input, output, session) {
         data(regicor)
         dataset <- regicor
       }
-      if (input$exampledata=='PREDIMED'){
-        data(predimed)
-        dataset <- predimed
-      }
       if (input$exampledata=='SNPS'){
-        data(SNPs,package="SNPassoc")
+        # data(SNPs,package="SNPassoc")
+        data(SNPs)
         dataset <- SNPs
       }
     } else { # read own data
@@ -1848,14 +1813,14 @@ server <- function(input, output, session) {
       validate(need(dd, "Data not loaded yet"))
       validate(need(input$plotselevars, "Select one variable"))
       perc<-if (is.null(input$perc)) FALSE else input$perc
-      if (!inherits(dd[,input$plotselevars],"factor"))
+      if (!inherits(dd[,input$plotselevars],"factor") | input$plotresptype=='Survival')
         hide("perc") 
       else 
         show("perc")
       if (!inherits(dd[,input$plotselevars],"Surv"))
-        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group","Survival")) 
+        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group","Survival"),selected=input$plotresptype) #@@
       else 
-        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group"))      
+        updateRadioGroupButtons(session, "plotresptype", choices=c("None","Group"),selected=input$plotresptype) #@@      
       withProgress(message = 'Making plot', value = 0, {
         if (is.null(input$plotresptype) || input$plotresptype=='None')
           form <- paste0("~",input$plotselevars)
@@ -1868,12 +1833,18 @@ server <- function(input, output, session) {
           dd$"respsurv"<-Surv(times,cens)
           form <- paste0("respsurv ~ ",input$plotselevars)
         }
+        if (!is.Surv(dd[,input$plotselevars]) & is.numeric(dd[,input$plotselevars])){
+          if (length(unique(dd[,input$plotselevars]))<5) showModal(modalDialog("Variable contains less than 5 unique values.\nConsider to convert it to factor"))
+          validate(need(length(unique(dd[,input$plotselevars]))>=5, ""))
+        }
         cg <- compareGroups(as.formula(form), dd)
+        print(cg)
         plot(cg,bivar=TRUE,perc=perc)
         # shinyjs::show("downPlotOptionsPanel")
         incProgress(1,detail="")
       })
       rv$plotcreated <- TRUE
+      if (!is.Surv(dd[,input$plotselevars]) & is.numeric(dd[,input$plotselevars]) & length(unique(dd[,input$plotselevars]))<5) rv$plotcreated <- FALSE
     })
   })
 
@@ -1946,9 +1917,8 @@ server <- function(input, output, session) {
                             "huge" = 24.88,
                             "Huge" = 24.88)
           export2pdf(restab,file=ff, size=sizepdf, landscape=input$landscape, header.labels=header.labels, caption=captionlabel,
-                     width=paste0(input$htmlwidthrestab,'cm'), strip=input$strip, first.strip=TRUE, background=input$strip.color)
-                     # ,
-                     # header.color=input$header.color,header.background=input$header.background)
+                     width=paste0(input$htmlwidthrestab,'cm'), strip=input$strip, first.strip=TRUE, background=input$strip.color,
+                     header.color=input$header.color,header.background=input$header.background)
         }
         if (input$downloadtabletype=='HTML'){
           ans <- export2md(restab,format='html',header.labels=header.labels,caption=captionlabel,
